@@ -10,7 +10,6 @@ from rich.segment import Segment, Segments
 from rich.style import Style, StyleType
 
 from . import events
-from ._types import MessageTarget
 from .geometry import Offset
 from .message import Message
 from .reactive import Reactive
@@ -47,7 +46,6 @@ class ScrollTo(ScrollMessage, verbose=True):
 
     def __init__(
         self,
-        sender: MessageTarget,
         x: float | None = None,
         y: float | None = None,
         animate: bool = True,
@@ -55,7 +53,7 @@ class ScrollTo(ScrollMessage, verbose=True):
         self.x = x
         self.y = y
         self.animate = animate
-        super().__init__(sender)
+        super().__init__()
 
     def __rich_repr__(self) -> rich.repr.Result:
         yield "x", self.x, None
@@ -293,6 +291,7 @@ class ScrollBar(Widget):
     def _on_hide(self, event: events.Hide) -> None:
         if self.grabbed:
             self.release_mouse()
+            self.grabbed = None
 
     def _on_enter(self, event: events.Enter) -> None:
         self.mouse_over = True
@@ -301,12 +300,12 @@ class ScrollBar(Widget):
         self.mouse_over = False
 
     def action_scroll_down(self) -> None:
-        self.post_message_no_wait(
-            ScrollDown(self) if self.vertical else ScrollRight(self)
-        )
+        if not self.grabbed:
+            self.post_message(ScrollDown() if self.vertical else ScrollRight())
 
     def action_scroll_up(self) -> None:
-        self.post_message_no_wait(ScrollUp(self) if self.vertical else ScrollLeft(self))
+        if not self.grabbed:
+            self.post_message(ScrollUp() if self.vertical else ScrollLeft())
 
     def action_grab(self) -> None:
         self.capture_mouse()
@@ -317,6 +316,7 @@ class ScrollBar(Widget):
     async def _on_mouse_up(self, event: events.MouseUp) -> None:
         if self.grabbed:
             self.release_mouse()
+            self.grabbed = None
         event.stop()
 
     def _on_mouse_capture(self, event: events.MouseCapture) -> None:
@@ -359,7 +359,7 @@ class ScrollBar(Widget):
                         * (virtual_size / self.window_size)
                     )
                 )
-            await self.post_message(ScrollTo(self, x=x, y=y))
+            self.post_message(ScrollTo(x=x, y=y))
         event.stop()
 
     async def _on_click(self, event: events.Click) -> None:
