@@ -1,4 +1,3 @@
-from os import terminal_size
 from pathlib import Path
 
 import pytest
@@ -73,8 +72,7 @@ def test_input_and_focus(snap_compare):
         "tab",
         *"Darren",  # Focus first input, write "Darren"
         "tab",
-        *"Burns",
-        "_",  # Tab focus to second input, write "Burns"
+        *"Burns",  # Focus second input, write "Burns"
     ]
     assert snap_compare(WIDGET_EXAMPLES_DIR / "input.py", press=press)
 
@@ -91,17 +89,17 @@ def test_placeholder_render(snap_compare):
 
 
 def test_datatable_render(snap_compare):
-    press = ["tab", "down", "down", "right", "up", "left", "_"]
+    press = ["tab", "down", "down", "right", "up", "left"]
     assert snap_compare(WIDGET_EXAMPLES_DIR / "data_table.py", press=press)
 
 
 def test_datatable_row_cursor_render(snap_compare):
-    press = ["up", "left", "right", "down", "down", "_"]
+    press = ["up", "left", "right", "down", "down"]
     assert snap_compare(SNAPSHOT_APPS_DIR / "data_table_row_cursor.py", press=press)
 
 
 def test_datatable_column_cursor_render(snap_compare):
-    press = ["left", "up", "down", "right", "right", "_"]
+    press = ["left", "up", "down", "right", "right"]
     assert snap_compare(SNAPSHOT_APPS_DIR / "data_table_column_cursor.py", press=press)
 
 
@@ -125,12 +123,12 @@ def test_header_render(snap_compare):
 
 def test_list_view(snap_compare):
     assert snap_compare(
-        WIDGET_EXAMPLES_DIR / "list_view.py", press=["tab", "down", "down", "up", "_"]
+        WIDGET_EXAMPLES_DIR / "list_view.py", press=["tab", "down", "down", "up"]
     )
 
 
 def test_textlog_max_lines(snap_compare):
-    assert snap_compare("snapshot_apps/textlog_max_lines.py", press=[*"abcde", "_"])
+    assert snap_compare("snapshot_apps/textlog_max_lines.py", press=[*"abcde"])
 
 
 def test_fr_units(snap_compare):
@@ -170,9 +168,11 @@ def test_content_switcher_example_initial(snap_compare):
 
 
 def test_content_switcher_example_switch(snap_compare):
-    assert snap_compare(WIDGET_EXAMPLES_DIR / "content_switcher.py", press=[
-        "tab", "tab", "enter", "wait:500"
-    ], terminal_size=(50, 50))
+    assert snap_compare(
+        WIDGET_EXAMPLES_DIR / "content_switcher.py",
+        press=["tab", "tab", "enter", "wait:500"],
+        terminal_size=(50, 50),
+    )
 
 
 # --- CSS properties ---
@@ -203,7 +203,7 @@ def test_order_independence(snap_compare):
 
 
 def test_order_independence_toggle(snap_compare):
-    assert snap_compare("snapshot_apps/layer_order_independence.py", press="t,_")
+    assert snap_compare("snapshot_apps/layer_order_independence.py", press="t")
 
 
 def test_columns_height(snap_compare):
@@ -218,7 +218,7 @@ def test_offsets(snap_compare):
 
 def test_nested_auto_heights(snap_compare):
     """Test refreshing widget within a auto sized container"""
-    assert snap_compare("snapshot_apps/nested_auto_heights.py", press=["1", "2", "_"])
+    assert snap_compare("snapshot_apps/nested_auto_heights.py", press=["1", "2"])
 
 
 def test_programmatic_scrollbar_gutter_change(snap_compare):
@@ -234,6 +234,7 @@ def test_programmatic_scrollbar_gutter_change(snap_compare):
 # --- CLI Preview Apps ---
 # For our CLI previews e.g. `textual easing`, `textual colors` etc, we have snapshots
 
+
 def test_borders_preview(snap_compare):
     assert snap_compare(CLI_PREVIEWS_DIR / "borders.py", press=["tab", "enter"])
 
@@ -295,4 +296,14 @@ def test_focus_component_class(snap_compare):
 
 
 def test_line_api_scrollbars(snap_compare):
-    assert snap_compare(SNAPSHOT_APPS_DIR / "line_api_scrollbars.py", press=["_"])
+    assert snap_compare(SNAPSHOT_APPS_DIR / "line_api_scrollbars.py")
+
+
+def test_remove_with_auto_height(snap_compare):
+    assert snap_compare(
+        SNAPSHOT_APPS_DIR / "remove_auto.py", press=["a", "a", "a", "d", "d"]
+    )
+
+
+def test_auto_table(snap_compare):
+    assert snap_compare(SNAPSHOT_APPS_DIR / "auto-table.py", terminal_size=(120, 40))
